from leaguepedia_parser.parsers.game_parser import (
    get_regions,
    get_tournaments,
    get_games,
    get_game_details,
)
from leaguepedia_parser.parsers.team_parser import (
    get_team_logo,
    get_long_team_name_from_trigram,
    get_team_thumbnail,
    get_all_team_assets
)
